/var/www/greso.tech/server/nsm/node_modules/es5-ext
NameSizeModeActions
array/-0755rm
boolean/-0755rm
date/-0755rm
error/-0755rm
function/-0755rm
iterable/-0755rm
json/-0755rm
math/-0755rm
number/-0755rm
object/-0755rm
promise/-0755rm
reg-exp/-0755rm
string/-0755rm
CHANGELOG.md137760644editdlrm
global.js11370644editdlrm
index.js6240644editdlrm
LICENSE7730644editdlrm
optional-chaining.js4320644editdlrm
package.json26360644editdlrm
README.md404000644editdlrm
safe-to-string.js2660644editdlrm
to-short-string-representation.js4130644editdlrm
_postinstall.js33180755editdlrm
Edit: /var/www/greso.tech/server/nsm/node_modules/es5-ext/global.js (1137B)
var naiveFallback = function () { if (typeof self === "object" && self) return self; if (typeof window === "object" && window) return window; throw new Error("Unable to resolve global `this`"); }; module.exports = (function () { if (this) return this; // Unexpected strict mode (may happen if e.g. bundled into ESM module) // Fallback to standard globalThis if available if (typeof globalThis === "object" && globalThis) return globalThis; // Thanks @mathiasbynens -> https://mathiasbynens.be/notes/globalthis // In all ES5+ engines global object inherits from Object.prototype // (if you approached one that doesn't please report) try { Object.defineProperty(Object.prototype, "__global__", { get: function () { return this; }, configurable: true }); } catch (error) { // Unfortunate case of updates to Object.prototype being restricted // via preventExtensions, seal or freeze return naiveFallback(); } try { // Safari case (window.__global__ works, but __global__ does not) if (!__global__) return naiveFallback(); return __global__; } finally { delete Object.prototype.__global__; } })();